#!/bin/bash
# Reproduction recipe for NV-7983 "Infinite Retries"
#
# Usage: test.sh [REPO_DIR [FS_TYPE]]
#   REPO_DIR will be overwritten; default './repo'
#   FS_TYPE: default 'fsfs'

set -e

#SVN_PREFIX=$HOME/.local/subversion-1
SVN_SRC_DIR=$HOME/src/subversion-c
SVN_OBJ_DIR=$HOME/build/subversion-c

HERE=$(dirname $(realpath $0))
REPO_DIR=$(realpath "${1:-./repo}")
FS_TYPE="${2:-fsfs}"

REPO_URL=file://$REPO_DIR

set -x

svn --version -q

rm -rf "$REPO_DIR"

# Create a repo
$HERE/create-repo.sh "$REPO_DIR" "$FS_TYPE"
# ... with some corrupted content
#$HERE/corrupt-repo.sh "$REPO_DIR"

# Try to commit using the FSFS API via Python bindings,
# and test whether first and second commits fail consistently.
#export PYTHONPATH=$SVN_PREFIX/lib/svn-python
export PYTHONPATH=$SVN_SRC_DIR/subversion/bindings/swig/python:$SVN_OBJ_DIR/subversion/bindings/swig/python:$SVN_OBJ_DIR/subversion/bindings/swig/python/.libs
export COMMIT_FAIL=0

for COMMIT_FAIL in 1 2 3 4 5 6 7 8 9; do
  $HERE/test-commits.py "$REPO_DIR" || echo "FAILED: sub-test $COMMIT_FAIL"
done
